@@ -1,10 +1,17 @@
-# ================================================================
+# ============================================================================
 package Business::UPS::Tracking::Shipment;
-# ================================================================
+# ============================================================================
 use utf8;
-use Moose;
 use 5.0100;
 
+use metaclass (
+    metaclass   => "Moose::Meta::Class",
+    error_class => "Business::UPS::Tracking::Exception",
+);
+use Moose;
+with qw(Business::UPS::Tracking::Role::Serialize
+    Business::UPS::Tracking::Role::Builder);
+
 use Business::UPS::Tracking::Utils;
 
 our $VERSION = $Business::UPS::Tracking::VERISON;
@@ -56,13 +63,10 @@ object.
 Shipment destination address. Returns a 
 L<Business::UPS::Tracking::Element::Address> object.
 
-=head2 ServiceCode
+=head2 Service
 
-UPS service code. (eg. '002' for 2nd day air)
-
-=head2 ServiceDescription
-
-UPS service code description (eg. '2ND DAY AIR')
+Service code and description. 
+Returns a L<Business::UPS::Tracking::Element::Code> object.
 
 =head2 ShipmentReferenceNumber
 
@@ -79,62 +83,65 @@ has 'xml' => (
 has 'ScheduledDelivery' => (
     is      => 'ro',
     isa     => 'Maybe[Date]',
-    lazy    => 1,
-    builder => '_build_ScheduledDelivery',
+    traits  => ['Serializable'],
+    lazy_build      => 1,
+    documentation   => 'Scheduled delivery date',
 );
 has 'PickupDate' => (
     is      => 'ro',
     isa     => 'Maybe[Date]',
-    lazy    => 1,
-    builder => '_build_PickupDate',
+    traits  => ['Serializable'],
+    documentation   => 'Pickup date',
+    lazy_build      => 1,
 );
 has 'ShipperNumber' => (
     is      => 'ro',
     isa     => 'Str',
-    lazy    => 1,
-    builder => '_build_ShipperNumber',
+    traits  => ['Serializable'],
+    documentation   => 'Shipper UPS customer number',
+    lazy_build      => 1,
 );
 has 'ShipperAddress' => (
     is      => 'ro',
     isa     => 'Maybe[Business::UPS::Tracking::Element::Address]',
-    lazy    => 1,
-    builder => '_build_ShipperAddress',
+    traits  => ['Serializable'],
+    documentation   => 'Shipper address',
+    lazy_build      => 1,
 );
 has 'ShipmentWeight' => (
     is      => 'ro',
     isa     => 'Maybe[Business::UPS::Tracking::Element::Weight]',
-    lazy    => 1,
-    builder => '_build_ShipmentWeight',
+    traits  => ['Serializable'],
+    documentation => 'Shipment weight',
+    lazy_build    => 1,
 );
 has 'ShipToAddress' => (
     is      => 'ro',
     isa     => 'Maybe[Business::UPS::Tracking::Element::Address]',
-    lazy    => 1,
-    builder => '_build_ShipToAddress',
+    traits  => ['Serializable'],
+    documentation   => 'Destination address',
+    lazy_build      => 1,
 );
-has 'ServiceCode' => (
+has 'Service' => (
     is      => 'ro',
-    isa     => 'Str',
-    lazy    => 1,
-    builder => '_build_ServiceCode',
-);
-has 'ServiceDescription' => (
-    is      => 'ro',
-    isa     => 'Str',
-    lazy    => 1,
-    builder => '_build_ServiceDescription',
+    isa     => 'Maybe[Business::UPS::Tracking::Element::Code]',
+    traits  => ['Serializable'],
+    documentation   => 'Service',
+    lazy_build      => 1,
 );
 has 'ReferenceNumber' => (
     is      => 'ro',
     isa     => 'Maybe[Business::UPS::Tracking::Element::ReferenceNumber]',
-    lazy    => 1,
-    builder => '_build_ReferenceNumber',
+    traits  => ['Serializable'],
+    documentation   => 'Reference number',
+    lazy_build      => 1,
 );
 has 'ShipmentIdentificationNumber' => (
     is      => 'ro',
     isa     => 'Str',
-    lazy    => 1,
-    builder => '_build_ShipmentIdentificationNumber',
+    traits  => ['Serializable'],
+    documentation   => 'Identification number',
+    lazy_build      => 1,
 );
 
 sub _build_ScheduledDelivery {
@@ -165,43 +172,31 @@ sub _build_ShipperNumber {
 sub _build_ShipperAddress {
     my ($self) = @_;
     
-    return Business::UPS::Tracking::Utils::build_address($self->xml,'Shipper/Address');
+    return $self->build_address('Shipper/Address');
 }
 
 sub _build_ShipmentWeight {
     my ($self) = @_;
     
-    my $node = $self->xml->findnodes('ShipmentWeight')->get_node(1);
-    return
-        unless $node;
-    return Business::UPS::Tracking::Element::Weight->new(
-        xml => $node
-    );
+    return $self->build_weight('ShipmentWeight');
 }
 
 sub _build_ShipToAddress {
     my ($self) = @_;
     
-    return Business::UPS::Tracking::Utils::build_address($self->xml,'ShipTo/Address');
+    return $self->build_address('ShipTo/Address');
 }
 
-
-sub _build_ServiceCode {
+sub _build_Service {
     my ($self) = @_;
     
-    return $self->xml->findvalue('Service/Code');
-}
-
-sub _build_ServiceDescription {
-    my ($self) = @_;
-    
-    return $self->xml->findvalue('Service/Description');
+    return $self->build_code('Service');
 }
 
 sub _build_ReferenceNumber {
     my ($self) = @_;
     
-    return Business::UPS::Tracking::Utils::build_referencenumber($self->xml,'ReferenceNumber');
+    return $self->build_referencenumber('ReferenceNumber');
 }
 
 sub _build_ShipmentIdentificationNumber {
@@ -211,10 +206,25 @@ sub _build_ShipmentIdentificationNumber {
         || undef;
 }
 
+=head1 METHODS
+
+=head2 ShipmentType
+
+Returns the shipment type. Either 'Freight' or 'Small Package'
+
+=cut
+
 sub ShipmentType {
     Business::UPS::Tracking::X->throw("__PACKAGE__ is an abstract class")
 }
 
+=head2 meta
+
+Moose meta method
+
+=cut
+
+
 __PACKAGE__->meta->make_immutable;
 
 1;
\ No newline at end of file
