@@ -17,6 +17,7 @@ sub import {
     no strict 'refs';
     *{ $caller . '::tracking' }    = \&tracking;
     *{ $caller . '::testrequest' } = \&testrequest;
+    *{ $caller . '::testcheck' } = \&testcheck;
 }
 
 sub tracking {
@@ -27,6 +28,17 @@ sub tracking {
     );
 }
 
+sub testcheck {
+    my ($skiptests) = @_;
+    
+    my $tracking = tracking();
+    my $url = $tracking->url();
+    $url =~ s/^(https?:\/\/.+\/).+$/$1/;
+    my $response = $tracking->_ua()->get($url);
+    
+    return $response->is_success;
+}
+
 sub testrequest {
     my (%params) = @_;
 
